Summary method
# S3 method for pseudoglm
summary(
object,
correlation = FALSE,
symbolic.cor = FALSE,
type = "robust",
...
)An object of class summary.glm
A pseudoglm object, as returned by cumincglm or rmeanglm
logical; if TRUE, the correlation matrix of the estimated parameters is returned and printed.
logical; If TRUE, print the correlations in a symbolic form rather than as numbers.
The method to use for variance estimation; one of "corrected", "robust", "naive", or "cluster"
Not used