leaveOneOut.survival: Compute leave one out jackknife contributions of the survival function
Description
For each subject, the survival function is recomputed leaving that subject out.
This one does the calculation for all observed times, for calculation of the restricted mean
Usage
leaveOneOut.survival(object, times, mr)
Value
A vector of jackknifed values of survival at time times
Arguments
object
A survfit object, with a single event (no competing risks)
times
Compute values at observed times up to and including this time
mr
Model response, the result of a call to Surv, or a matrix with two columns: "time" (observed follow up time) and "status" (0 = censored, 1 = event)